@@ -9,7 +9,7 @@
 // be copied from the old stdplane. Assumes that the screen is always anchored at
 // the same origin. Also syncs up lastframe.
 static int
-notcurses_resize(notcurses* n, int* restrict rows, int* restrict cols){
+notcurses_resize_internal(notcurses* n, int* restrict rows, int* restrict cols){
   int r, c;
   if(rows == NULL){
     rows = &r;
@@ -64,6 +64,14 @@ notcurses_resize(notcurses* n, int* restrict rows, int* restrict cols){
   return 0;
 }
 
+static int
+notcurses_resize(notcurses* n, int* restrict rows, int* restrict cols){
+  pthread_mutex_lock(&n->pilelock);
+  int ret = notcurses_resize_internal(n, rows, cols);
+  pthread_mutex_unlock(&n->pilelock);
+  return ret;
+}
+
 static int
 blocking_write(int fd, const char* buf, size_t buflen){
 //fprintf(stderr, "writing %zu to %d...\n", buflen, fd);
@@ -203,33 +211,6 @@ highcontrast(uint32_t bchannel){
   return conrgb;
 }
 
-// adjust an otherwise locked-in cell if highcontrast has been requested. this
-// should be done at the end of rendering the cell, so that contrast is solved
-// against the real background.
-static inline void
-lock_in_highcontrast(cell* targc, struct crender* crender){
-  if(cell_fg_alpha(targc) == CELL_ALPHA_TRANSPARENT){
-    cell_set_fg_default(targc);
-  }
-  if(cell_bg_alpha(targc) == CELL_ALPHA_TRANSPARENT){
-    cell_set_bg_default(targc);
-  }
-  if(crender->highcontrast){
-    // highcontrast weighs the original at 1/4 and the contrast at 3/4
-    if(!cell_fg_default_p(targc)){
-      crender->fgblends = 3;
-      uint32_t fchan = cell_fchannel(targc);
-      uint32_t bchan = cell_bchannel(targc);
-      uint32_t hchan = channels_blend(highcontrast(bchan), fchan, &crender->fgblends);
-      cell_set_fchannel(targc, hchan);
-      hchan = channels_blend(hchan, crender->hcfg, &crender->hcfgblends);
-      cell_set_fchannel(targc, hchan);
-    }else{
-      cell_set_fg_rgb(targc, highcontrast(cell_bchannel(targc)));
-    }
-  }
-}
-
 // Paints a single ncplane 'p' into the provided scratch framebuffer 'fb' (we
 // can't always write directly into lastframe, because we need build state to
 // solve certain cells, and need compare their solved result to the last frame).
@@ -375,6 +356,37 @@ init_rvec(struct crender* rvec, int totalcells){
   }
 }
 
+// adjust an otherwise locked-in cell if highcontrast has been requested. this
+// should be done at the end of rendering the cell, so that contrast is solved
+// against the real background.
+static inline void
+lock_in_highcontrast(cell* targc, struct crender* crender){
+  if(cell_fg_alpha(targc) == CELL_ALPHA_TRANSPARENT){
+    cell_set_fg_default(targc);
+  }
+  if(cell_bg_alpha(targc) == CELL_ALPHA_TRANSPARENT){
+    cell_set_bg_default(targc);
+  }
+  if(crender->highcontrast){
+    // highcontrast weighs the original at 1/4 and the contrast at 3/4
+    if(!cell_fg_default_p(targc)){
+      crender->fgblends = 3;
+      uint32_t fchan = cell_fchannel(targc);
+      uint32_t bchan = cell_bchannel(targc);
+      uint32_t hchan = channels_blend(highcontrast(bchan), fchan, &crender->fgblends);
+      cell_set_fchannel(targc, hchan);
+      hchan = channels_blend(hchan, crender->hcfg, &crender->hcfgblends);
+      cell_set_fchannel(targc, hchan);
+    }else{
+      cell_set_fg_rgb(targc, highcontrast(cell_bchannel(targc)));
+    }
+  }
+}
+
+// iterate over the rendered frame, adjusting the foreground colors for any
+// cells marked CELL_ALPHA_HIGHCONTRAST, and clearing any cell covered by a
+// wide glyph to its left. FIXME why can't we do this as we go along? FIXME can
+// we not do the blend a single time here, if we track sums in paint()?
 static void
 postpaint(cell* lastframe, int dimy, int dimx, struct crender* rvec, egcpool* pool){
   for(int y = 0 ; y < dimy ; ++y){
@@ -405,6 +417,8 @@ postpaint(cell* lastframe, int dimy, int dimx, struct crender* rvec, egcpool* po
   }
 }
 
+// merging one plane down onto another is basically just performing a render
+// using only these two planes, with the result written to the lower plane.
 int ncplane_mergedown(const ncplane* restrict src, ncplane* restrict dst,
                       int begsrcy, int begsrcx, int leny, int lenx,
                       int dsty, int dstx){
@@ -755,7 +769,8 @@ goto_location(notcurses* nc, FILE* out, int y, int x){
 // lastframe has *not yet been written to the screen*, i.e. it's only about to
 // *become* the last frame rasterized.
 static int
-notcurses_rasterize_inner(notcurses* nc, const struct crender* rvec, FILE* out){
+notcurses_rasterize_inner(notcurses* nc, const ncpile* p, FILE* out){
+  const struct crender* rvec = p->crender;
   int y, x;
   fseeko(out, 0, SEEK_SET);
   // we only need to emit a coordinate if it was damaged. the damagemap is a
@@ -764,6 +779,7 @@ notcurses_rasterize_inner(notcurses* nc, const struct crender* rvec, FILE* out){
   // we explicitly move the cursor at the beginning of each output line, so no
   // need to home it expliticly.
   update_palette(nc, out);
+  // FIXME need adapt this to piles
   for(y = nc->stdplane->absy ; y < nc->stdplane->leny + nc->stdplane->absy ; ++y){
     const int innery = y - nc->stdplane->absy;
     for(x = nc->stdplane->absx ; x < nc->stdplane->lenx + nc->stdplane->absx ; ++x){
@@ -914,8 +930,8 @@ notcurses_rasterize_inner(notcurses* nc, const struct crender* rvec, FILE* out){
 
 // rasterize the rendered frame, and blockingly write it out to the terminal.
 static int
-raster_and_write(notcurses* nc, const struct crender* rvec, FILE* out){
-  if(notcurses_rasterize_inner(nc, rvec, out) < 0){
+raster_and_write(notcurses* nc, const ncpile* p, FILE* out){
+  if(notcurses_rasterize_inner(nc, p, out) < 0){
     return -1;
   }
   int ret = 0;
@@ -938,13 +954,13 @@ raster_and_write(notcurses* nc, const struct crender* rvec, FILE* out){
 // during rasterization, we'll get grotesque flicker. 'out' is a memstream
 // used to collect a buffer.
 static inline int
-notcurses_rasterize(notcurses* nc, const struct crender* rvec, FILE* out){
+notcurses_rasterize(notcurses* nc, const ncpile* p, FILE* out){
   const int cursory = nc->cursory;
   const int cursorx = nc->cursorx;
   if(cursory >= 0){ // either both are good, or neither is
     notcurses_cursor_disable(nc);
   }
-  int ret = raster_and_write(nc, rvec, out);
+  int ret = raster_and_write(nc, p, out);
   if(cursory >= 0){
     notcurses_cursor_enable(nc, cursory, cursorx);
   }
@@ -980,18 +996,21 @@ int notcurses_refresh(notcurses* nc, int* restrict dimy, int* restrict dimx){
   if(home_cursor(nc, true)){
     return -1;
   }
-  const int count = (nc->lfdimx > nc->stdplane->lenx ? nc->lfdimx : nc->stdplane->lenx) *
-                    (nc->lfdimy > nc->stdplane->leny ? nc->lfdimy : nc->stdplane->leny);
-  struct crender* rvec = malloc(count * sizeof(*rvec));
-  if(rvec == NULL){
+  ncpile p;
+  p.dimy = nc->stdplane->leny;
+  p.dimx = nc->stdplane->lenx;
+  const int count = (nc->lfdimx > p.dimx ? nc->lfdimx : p.dimx) *
+                    (nc->lfdimy > p.dimy ? nc->lfdimy : p.dimy);
+  p.crender = malloc(count * sizeof(*p.crender));
+  if(p.crender == NULL){
     return -1;
   }
-  memset(rvec, 0, count * sizeof(*rvec));
+  memset(p.crender, 0, count * sizeof(*p.crender));
   for(int i = 0 ; i < count ; ++i){
-    rvec[i].damaged = true;
+    p.crender[i].damaged = true;
   }
-  int ret = notcurses_rasterize(nc, rvec, nc->rstate.mstreamfp);
-  free(rvec);
+  int ret = notcurses_rasterize(nc, &p, nc->rstate.mstreamfp);
+  free(p.crender);
   if(ret < 0){
     return -1;
   }
@@ -1008,20 +1027,23 @@ int notcurses_render_to_file(notcurses* nc, FILE* fp){
   if(out == NULL){
     return -1;
   }
-  const int count = (nc->lfdimx > nc->stdplane->lenx ? nc->lfdimx : nc->stdplane->lenx) *
-                    (nc->lfdimy > nc->stdplane->leny ? nc->lfdimy : nc->stdplane->leny);
-  struct crender* rvec = malloc(count * sizeof(*rvec));
-  if(rvec == NULL){
+  ncpile p;
+  p.dimy = nc->stdplane->leny;
+  p.dimx = nc->stdplane->lenx;
+  const int count = (nc->lfdimx > p.dimx ? nc->lfdimx : p.dimx) *
+                    (nc->lfdimy > p.dimy ? nc->lfdimy : p.dimy);
+  p.crender = malloc(count * sizeof(*p.crender));
+  if(p.crender == NULL){
     fclose(out);
     free(rastered);
     return -1;
   }
-  memset(rvec, 0, count * sizeof(*rvec));
+  memset(p.crender, 0, count * sizeof(*p.crender));
   for(int i = 0 ; i < count ; ++i){
-    rvec[i].damaged = true;
+    p.crender[i].damaged = true;
   }
-  int ret = raster_and_write(nc, rvec, out);
-  free(rvec);
+  int ret = raster_and_write(nc, &p, out);
+  free(p.crender);
   if(ret > 0){
     if(fprintf(fp, "%s", rastered) == ret){
       ret = 0;
@@ -1053,58 +1075,59 @@ ncpile_render_internal(ncplane* n, struct crender* rvec, int leny, int lenx,
 int ncpile_rasterize(ncplane* n){
   struct timespec start, writedone;
   clock_gettime(CLOCK_MONOTONIC, &start);
-  int dimy, dimx;
-  const struct ncpile* pile = ncplane_pile(n);
-  notcurses_resize(ncplane_notcurses(n), &dimy, &dimx);
-  postpaint(ncplane_notcurses(n)->lastframe, dimy, dimx, pile->crender,
-            &ncplane_notcurses(n)->pool);
-  int bytes = notcurses_rasterize(ncplane_notcurses(n), pile->crender,
-                                  ncplane_notcurses(n)->rstate.mstreamfp);
+  const ncpile* pile = ncplane_pile(n);
+  struct notcurses* nc = ncplane_notcurses(n);
+  const int miny = pile->dimy < nc->lfdimy ? pile->dimy : nc->lfdimy;
+  const int minx = pile->dimx < nc->lfdimx ? pile->dimx : nc->lfdimx;
+  postpaint(nc->lastframe, miny, minx, pile->crender, &nc->pool);
+  int bytes = notcurses_rasterize(nc, pile, nc->rstate.mstreamfp);
   // accepts -1 as an indication of failure
-  update_render_bytes(&ncplane_notcurses(n)->stats, bytes);
+  update_render_bytes(&nc->stats, bytes);
   if(bytes < 0){
     return -1;
   }
   clock_gettime(CLOCK_MONOTONIC, &writedone);
-  update_write_stats(&writedone, &start, &ncplane_notcurses(n)->stats);
+  update_write_stats(&writedone, &start, &nc->stats);
   return 0;
 }
 
 // ensure the crender vector of 'n' is sufficiently large for 'dimy'x'dimx'
 static int
 engorge_crender_vector(ncpile* n, int dimy, int dimx){
-  const size_t crenderlen = sizeof(struct crender) * dimy * dimx;
-  if(crenderlen > n->crenderlen){
-    struct crender* tmp = realloc(n->crender, crenderlen);
+  const int crenderlen = dimy * dimx;
+  if(crenderlen > n->dimy * n->dimx){
+    struct crender* tmp = realloc(n->crender, sizeof(*tmp) * crenderlen);
     if(tmp == NULL){
       return -1;
     }
     n->crender = tmp;
-    n->crenderlen = crenderlen;
+    n->dimy = dimy;
+    n->dimx = dimx;
   }
-  init_rvec(n->crender, crenderlen / sizeof(struct crender));
+  init_rvec(n->crender, crenderlen);
   return 0;
 }
 
 int ncpile_render(ncplane* n){
+  notcurses* nc = ncplane_notcurses(n);
+  int dimy, dimx;
+  // update our notion of screen geometry, and render against that
+  notcurses_resize(nc, &dimy, &dimx);
   struct timespec start, renderdone;
   clock_gettime(CLOCK_MONOTONIC, &start);
-  int dimy, dimx;
-  // render against our current notion of screen geometry
-  ncplane_dim_yx(notcurses_stdplane(ncplane_notcurses(n)), &dimy, &dimx);
   if(engorge_crender_vector(ncplane_pile(n), dimy, dimx)){
     return -1;
   }
   ncpile_render_internal(n, ncplane_pile(n)->crender, dimy, dimx,
-                         notcurses_stdplane(ncplane_notcurses(n))->absy,
-                         notcurses_stdplane(ncplane_notcurses(n))->absx);
+                         notcurses_stdplane(nc)->absy,
+                         notcurses_stdplane(nc)->absx);
   clock_gettime(CLOCK_MONOTONIC, &renderdone);
-  update_render_stats(&renderdone, &start, &ncplane_notcurses(n)->stats);
+  update_render_stats(&renderdone, &start, &nc->stats);
   return 0;
 }
 
 int notcurses_render(notcurses* nc){
-  struct ncplane* stdn = notcurses_stdplane(nc);
+  ncplane* stdn = notcurses_stdplane(nc);
   if(ncpile_render(stdn)){
     return -1;
   }
@@ -1115,11 +1138,11 @@ int notcurses_render(notcurses* nc){
 // memstream from within rstate. we want to allocate our own here, and return
 // it, to avoid the copy, but we need feed the params through to do so FIXME.
 int notcurses_render_to_buffer(notcurses* nc, char** buf, size_t* buflen){
-  struct ncplane* stdn = notcurses_stdplane(nc);
+  ncplane* stdn = notcurses_stdplane(nc);
   if(ncpile_render(stdn)){
     return -1;
   }
-  int bytes = notcurses_rasterize_inner(nc, ncplane_pile(stdn)->crender, nc->rstate.mstreamfp);
+  int bytes = notcurses_rasterize_inner(nc, ncplane_pile(stdn), nc->rstate.mstreamfp);
   update_render_bytes(&nc->stats, bytes);
   if(bytes < 0){
     return -1;
